@@ -206,8 +206,8 @@ class ObjectVersionChecker(object):
         """Follow a chain of remotable things down to the original function."""
         if isinstance(thing, classmethod):
             return self._find_remotable_method(cls, thing.__get__(None, cls))
-        elif (inspect.ismethod(thing)
-              or inspect.isfunction(thing)) and hasattr(thing, 'remotable'):
+        elif (inspect.ismethod(thing) or
+              inspect.isfunction(thing)) and hasattr(thing, 'remotable'):
             return self._find_remotable_method(cls, thing.original_fn,
                                                parent_was_remotable=True)
         elif parent_was_remotable:
@@ -320,8 +320,9 @@ class ObjectVersionChecker(object):
         kwargs = {'version_manifest': manifest} if manifest else {}
         for n in range(version[1] + 1):
             test_version = '%d.%d' % (version[0], n)
-            LOG.info('testing obj: %s version: %s' %
-                     (obj_class.obj_name(), test_version))
+            # Run the test with OS_DEBUG=True to see this.
+            LOG.debug('testing obj: %s version: %s' %
+                      (obj_class.obj_name(), test_version))
             kwargs['target_version'] = test_version
             obj_class(*init_args, **init_kwargs).obj_to_primitive(**kwargs)
 
@@ -369,12 +370,13 @@ class ObjectVersionChecker(object):
             for my_version, child_version in versions:
                 _my_version = vutils.convert_version_to_tuple(my_version)
                 _ch_version = vutils.convert_version_to_tuple(child_version)
-                assert (last_my_version < _my_version
-                        and last_child_version <= _ch_version), \
-                    ('Object %s relationship '
-                     '%s->%s for field %s is out of order') % (
-                         obj_class.obj_name(), my_version,
-                         child_version, field)
+                if not (last_my_version < _my_version and
+                        last_child_version <= _ch_version):
+                    raise AssertionError(('Object %s relationship %s->%s for '
+                                          'field %s is out of order') % (
+                                              obj_class.obj_name(),
+                                              my_version, child_version,
+                                              field))
                 last_my_version = _my_version
                 last_child_version = _ch_version
 
