@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #    Copyright 2013 Red Hat, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,6 +14,7 @@
 #    under the License.
 
 import datetime
+import warnings
 
 import iso8601
 import mock
@@ -158,7 +160,7 @@ class TestString(TestField):
         self.coerce_good_values = [
             ('foo', 'foo'), (1, '1'), (1.0, '1.0'), (True, 'True')]
         if six.PY2:
-            self.coerce_good_values += [(long(1), '1')]
+            self.coerce_good_values += [(long(1), '1')]  # noqa
         self.coerce_bad_values = [None]
         self.to_primitive_values = self.coerce_good_values[0:1]
         self.from_primitive_values = self.coerce_good_values[0:1]
@@ -284,6 +286,9 @@ class TestUUID(TestField):
             ('da66a411-af0e-4829-9b67-475017ddz152',
                 'da66a411-af0e-4829-9b67-475017ddz152'),
             ('fake_uuid', 'fake_uuid'),
+            (u'fake_uāid', u'fake_uāid'),
+            (b'fake_u\xe1id'.decode('latin_1'),
+                b'fake_u\xe1id'.decode('latin_1')),
             ('1', '1'),
             (1, '1')
         ]
@@ -296,6 +301,11 @@ class TestUUID(TestField):
         self.test_from_primitive()
         self.test_to_primitive()
 
+    def test_validation_warning_can_be_escalated_to_exception(self):
+        warnings.filterwarnings(action='error')
+        self.assertRaises(FutureWarning, self.field.coerce, 'obj', 'attr',
+                          'not a uuid')
+
     def test_get_schema(self):
         field = fields.UUIDField()
         schema = field.get_schema()
@@ -803,6 +813,15 @@ class TestSetOfIntegers(TestField):
     def test_stringify(self):
         self.assertEqual('set([1,2])', self.field.stringify(set([1, 2])))
 
+    def test_repr(self):
+        self.assertEqual("Set(default=<class 'oslo_versionedobjects.fields."
+                         "UnspecifiedDefault'>,nullable=False)",
+                         repr(self.field))
+        self.assertEqual("Set(default=set([]),nullable=False)",
+                         repr(fields.SetOfIntegersField(default=set())))
+        self.assertEqual("Set(default=set([1,a]),nullable=False)",
+                         repr(fields.SetOfIntegersField(default={1, 'a'})))
+
 
 class TestListOfSetsOfIntegers(TestField):
     def setUp(self):
@@ -832,6 +851,24 @@ class TestListOfIntegers(TestField):
         self.assertEqual('[[1, 2]]', self.field.stringify([[1, 2]]))
 
 
+class TestListOfUUIDField(TestField):
+    def setUp(self):
+        super(TestListOfUUIDField, self).setUp()
+        self.field = fields.ListOfUUIDField()
+        self.uuid1 = '6b2097ea-d0e3-44dd-b131-95472b3ea8fd'
+        self.uuid2 = '478c193d-2533-4e71-ab2b-c7683f67d7f9'
+        self.coerce_good_values = [([self.uuid1, self.uuid2],
+                                    [self.uuid1, self.uuid2])]
+        # coerce_bad_values is intentionally ignored since the UUID field
+        # allows non-UUID values for now. See TestUUIDField for examples.
+        self.to_primitive_values = [([self.uuid1], [self.uuid1])]
+        self.from_primitive_values = [([self.uuid1], [self.uuid1])]
+
+    def test_stringify(self):
+        self.assertEqual('[%s,%s]' % (self.uuid1, self.uuid2),
+                         self.field.stringify([self.uuid1, self.uuid2]))
+
+
 class TestLocalMethods(test.TestCase):
     @mock.patch.object(obj_base.LOG, 'exception')
     def test__make_class_properties_setter_value_error(self, mock_log):
@@ -1192,3 +1229,41 @@ class TestIPV6Network(TestField):
         invalid_vals = [x for x in self.coerce_bad_values]
         for invalid_val in invalid_vals:
             self.assertNotRegex(str(invalid_val), pattern)
+
+
+class FakeCounter(six.Iterator):
+    def __init__(self):
+        self.n = 0
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        if self.n <= 4:
+            self.n += 1
+            return self.n
+        else:
+            raise StopIteration
+
+
+class TestListTypes(test.TestCase):
+
+    def test_regular_list(self):
+        fields.List(fields.Integer).coerce(None, None, [1, 2])
+
+    def test_non_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None, 2)
+
+    def test_string_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None,
+                          'hello')
+
+    def test_mapping_iterable(self):
+        self.assertRaises(ValueError,
+                          fields.List(fields.Integer).coerce, None, None,
+                          {'a': 1, 'b': 2})
+
+    def test_iter_class(self):
+        fields.List(fields.Integer).coerce(None, None, FakeCounter())
